      subroutine readflux
********************************************************************
*                                                                  *
*                     Author: P. JAMES                             *
*                     2000-03-29                                   *
*                                                                  *
********************************************************************
*                                                                  *
* DESCRIPTION: This program reads accumulated values of            *
*                                                                  *
*     QUANTITY                     MARS ABBR    CODE               *
*                                                                  *
*     large scale precipitation       LSP       142                *
*     convective precipitation        CP        143                *
*     surface sensible heat flux      SSHF      146                *
*     surface solar radiation         SSR       176                *
*     u stress                        EWSS      180                *
*     v stress                        NSSS      181                * 
*                                                                  *
*        from the following input files:                           *
*                                                                  *
*              surf_06_ub: first guess surface data 00/06/12/18    *
* if jhrf=3, also surf_03_ub: first guess surf. data 03/09/15/21)  *
*                                                                  *
* All input data files have to be unblocked grib code.             *
*                                                                  *
********************************************************************
      include 'parameter'
      include 'commonvar'

      integer kunit1,kunit2,ierr,lenght,iword,i,j,itime
      integer idnum(12),itges,ijp
      integer ij,im,id,ih,idel,ind,ic,jmd,hms,jout
      integer INBUFF(IDIMENS*4),ISEC0(2),ISEC1(56)
      integer ISEC2(22+nx+ny),ISEC3(2),ISEC4(42)
      real ZSEC2(122),ZSEC3(2),ZSEC4(IDIMENS*16)

      character*35 fname1,fname2
      character*1 mode

      double precision jul,juldate
C
C Change directory info below 
C
      data fname1 /'/scratch/ms/spdetraj/xxx/surf_06_ub'/
      data fname2 /'/scratch/ms/spdetraj/xxx/surf_03_ub'/
      data idnum /31,0,31,30,31,30,31,31,30,31,30,31/
*
      mode='D'
      call PBOPEN(kunit1,fname1,'r',ierr)
      if(ierr.lt.0) stop ' SUBROUTINE PBOPEN: ERROR OPENING FILE'
      if (jhrf.eq.3) then
      call PBOPEN(kunit2,fname2,'r',ierr)
      if(ierr.lt.0) stop ' SUBROUTINE PBOPEN: ERROR OPENING FILE'
      end if
*
* SKIP FIRST TIME, WHICH CANNOT BE UTILISED
*
      do 5 ind=1,6
        call PBGRIB(kunit1,INBUFF,IDIMENS*8,lenght,ierr)
        call GRIBEX(ISEC0,ISEC1,ISEC2,ZSEC2,ISEC3,ZSEC3,ISEC4,
     &              ZSEC4,IDIMENS,INBUFF,IDIMENS*4,iword,mode,ierr)
        jout=ISEC0(1)
5     continue

      do 90 ijp=1,3
* if jhrf=6, then first 3 times to pre-read are 6-hourly
* and are read from kunit1 (06,12,18)
* if jhrf=3, then alternates kunit2,kunit1,kunit2 (03,06,09)
      do 100 ind=1,6
        if (jhrf.eq.3.and.(mod(ijp,2).eq.1)) then
        call PBGRIB(kunit2,INBUFF,IDIMENS*8,lenght,ierr)
        else
        call PBGRIB(kunit1,INBUFF,IDIMENS*8,lenght,ierr)
        end if
        if(ierr.eq.-1) stop 'ERROR: EOF DETECTED AT TIME<3'
        if(ierr.lt.-1) stop 'SORRY: GRIB READ ERROR DETECTED'
        if(ierr.ne.0) stop 'SORRY: GRIB READ ERROR DETECTED'
        call GRIBEX (ISEC0,ISEC1,ISEC2,ZSEC2,ISEC3,ZSEC3,ISEC4,
     &               ZSEC4,IDIMENS,INBUFF,IDIMENS*8,iword,mode,ierr)
        if(ierr.ne.0) stop 'SORRY: GRIB CONVERSION ERROR DETECTED'
        ic=isec1(21)-1
        ij=isec1(10)
        im=isec1(11)
        id=isec1(12)
        ih=isec1(13)
        idel=isec1(16)
        jmd=ic*1000000+ij*10000+im*100+id
        hms=ih*10000
        jul=juldate(jmd,hms)
        jul=jul+dble(idel)/dble(24.0)
        call caldate(jul,jmd,hms)
c        idate(ijp)=(jmd-ic*1000000)*100+hms/10000
        idate(ijp)=jmd*100+hms/10000
c        if(ind.eq.1) write(*,'(a,i8.8)') 'DATE: ',idate(ijp)
        if(ind.eq.1) write(*,'(a,i10.10)') 'DATE: ',idate(ijp)
        if(mod(ih,3).ne.0) stop 'SORRY: ILLEGAL TIME DETECTED'      
        do 50 i=1,nx
          do 50 j=1,ny
            if(isec1(6).eq.142) lsp (i,j,ijp)=zsec4(nx*(ny-j)+i)
            if(isec1(6).eq.143) cp  (i,j,ijp)=zsec4(nx*(ny-j)+i)
            if(isec1(6).eq.146) sshf(i,j,ijp)=zsec4(nx*(ny-j)+i)
            if(isec1(6).eq.176) ssr (i,j,ijp)=zsec4(nx*(ny-j)+i)
            if(isec1(6).eq.180) ewss(i,j,ijp)=zsec4(nx*(ny-j)+i)
            if(isec1(6).eq.181) nsss(i,j,ijp)=zsec4(nx*(ny-j)+i)
50      continue
        if(isec1(6).eq.142) then
          write(*,'(6x,a,4x,i3)') 
     &      'FINISHED: LSP ',isec1(6)
        endif
        if(isec1(6).eq.143) then
          write(*,'(6x,a,4x,i3)') 
     &      'FINISHED: CP  ',isec1(6)
        endif
        if(isec1(6).eq.146) then
          write(*,'(6x,a,4x,i3)') 
     &      'FINISHED: SSHF',isec1(6)
        endif
        if(isec1(6).eq.176) then
          write(*,'(6x,a,4x,i3)') 
     &      'FINISHED: SSR ',isec1(6)
        endif
        if(isec1(6).eq.180) then
          write(*,'(6x,a,4x,i3)') 
     &      'FINISHED: EWSS',isec1(6)
        endif
        if(isec1(6).eq.181) then
          write(*,'(6x,a,4x,i3)') 
     &      'FINISHED: NSSS',isec1(6)
        endif
100   continue
*
* Convert fluxes to consistent 3- or 6- hourly RATEs
      call rate(ijp)
90    continue
*
* Now loop over remaining available times
      itime=3
10    itime=itime+1
      if(itime.gt.maxtime) then
         write(*,*) 'NOTE: MAX. ALLOWED TIMESTEPS EXCEEDED'
         goto 300
      endif
*
      do 200 ind=1,6
        if (jhrf.eq.3.and.(mod(itime,2).eq.1)) then
        call PBGRIB(kunit2,INBUFF,IDIMENS*8,lenght,ierr)
        else
        call PBGRIB(kunit1,INBUFF,IDIMENS*8,lenght,ierr)
        end if
        if(ierr.eq.-1) goto 300   ! EOF DETECTED
        if(ierr.lt.-1) stop 'SORRY: GRIB READ ERROR DETECTED'
        call GRIBEX (ISEC0,ISEC1,ISEC2,ZSEC2,ISEC3,ZSEC3,ISEC4,
     &               ZSEC4,IDIMENS,INBUFF,IDIMENS*8,iword,mode,ierr)
        if(ierr.ne.0) stop 'SORRY: GRIB CONVERSION ERROR DETECTED'
        ic=isec1(21)-1
        ij=isec1(10)
        im=isec1(11)
        id=isec1(12)
        ih=isec1(13)
        idel=isec1(16)
        jmd=ic*1000000+ij*10000+im*100+id
        hms=ih*10000
        jul=juldate(jmd,hms)
        jul=jul+dble(idel)/dble(24.0)
        call caldate(jul,jmd,hms)
c        idate(itime)=(jmd-ic*1000000)*100+hms/10000
        idate(itime)=jmd*100+hms/10000
c        if(ind.eq.1) write(*,'(a,i8.8)') 'DATE: ',idate(itime)
        if(ind.eq.1) write(*,'(a,i10.10)') 'DATE: ',idate(itime)
        if(mod(ih,3).ne.0) stop 'SORRY: ILLEGAL TIME DETECTED' 

        do 150 i=1,nx
          do 150 j=1,ny
            if(isec1(6).eq.142) lsp (i,j,4)=zsec4(nx*(ny-j)+i)
            if(isec1(6).eq.143) cp  (i,j,4)=zsec4(nx*(ny-j)+i)
            if(isec1(6).eq.146) sshf(i,j,4)=zsec4(nx*(ny-j)+i)
            if(isec1(6).eq.176) ssr (i,j,4)=zsec4(nx*(ny-j)+i)
            if(isec1(6).eq.180) ewss(i,j,4)=zsec4(nx*(ny-j)+i)
            if(isec1(6).eq.181) nsss(i,j,4)=zsec4(nx*(ny-j)+i)
150     continue
        if(isec1(6).eq.142) then
          write(*,'(6x,a,4x,i3)') 
     &      'FINISHED: LSP ',isec1(6)
        endif
        if(isec1(6).eq.143) then
          write(*,'(6x,a,4x,i3)') 
     &      'FINISHED: CP  ',isec1(6)
        endif
        if(isec1(6).eq.146) then
          write(*,'(6x,a,4x,i3)') 
     &      'FINISHED: SSHF',isec1(6)
        endif
        if(isec1(6).eq.176) then
          write(*,'(6x,a,4x,i3)') 
     &      'FINISHED: SSR ',isec1(6)
        endif
        if(isec1(6).eq.180) then
          write(*,'(6x,a,4x,i3)') 
     &      'FINISHED: EWSS',isec1(6)
        endif
        if(isec1(6).eq.181) then
          write(*,'(6x,a,4x,i3)') 
     &      'FINISHED: NSSS',isec1(6)
        endif
200   continue
*
* Convert fluxes to consistent 3- or 6- hourly RATEs
      call rate(itime)
*
* Check time
      if (idate(itime-1).gt.idate(itime)) then
         stop 'ERROR: TIMES FOR FLUX DATA NOT CORRECT'
      end if
*
* Interpolate deaccumulated fluxes with a cubic-polynomial solution
* or with a modified linear solution for rainfall
      call darain(lsp,lspi)
      call darain(cp,cpi)
      call dapoly(sshf,sshfi)
      call dapoly(ssr,ssri)
      call dapoly(ewss,ewssi)
      call dapoly(nsss,nsssi)
*
* Write out interpolated / deacc. fields at this timestep
      call writeout(itime,ISEC0,ISEC1,ISEC2,ZSEC2,ISEC3,
     & ZSEC3,ISEC4,ZSEC4,INBUFF,iword)

      call daback(lsp)
      call daback(cp)
      call daback(sshf)
      call daback(ssr)
      call daback(ewss)
      call daback(nsss)

      goto 10
*
* CLOSING INPUT DATA FILES
*
300   continue
      call pbclose(kunit1,ierr) 
      if (jhrf.eq.3) then
         call pbclose(kunit2,ierr)
      end if

      return
      end 
