      subroutine create_job(jmd,ih,resol,llon,rlon,blat,tlat,
     &  nuvz,nwz,nlev_ec,ktrunc,firstcall,update,new3dvar,
     &  uname,instdir,fluxdir,metedir)
*****************************************************************
*                                                               *
*               AUTHOR: G. WOTAWA, P. JAMES                     *
*               LAST UPDATE: 2000-12-21                         *
*                                                               *
*        ******************************************             *
*        * W O R K S T A T I O N    V E R S I O N *             *
*        ******************************************             *
*                                                               *
*****************************************************************
*                                                               *
* DESCRIPTION: CREATING OF JOB FILE NEEDED FOR PREPARATION OF   *
* METEOROLOGICAL DATA FOR TRAJECTORY MODEL FLEXTRA              *
*                                                               *
* THIS VERSION FOR DATES FROM 2000-09-12 FOLLOWING THE          *
* DISCONTINUTION OF FIRST-GUESS FIELDS                          *
* UTILISES 4D-VAR OPTIMIZED FIELDS (4V IN MARS)                 *
*                                                               *
*****************************************************************
*                                                               *
* INPUT:                                                        *
*                                                               *
* (1) General job specifications:                               *
*                                                               *
* jmd     date of data extraction (jjjjmmdd)                    *
* ih      hour of data extraction (hh)                          *
*                                                               *
* (2) Grid specifications:                                      *
*                                                               *
* resol   spatial resolution (DEG)                              *
* llon    lower left logitude (DEG)                             *
* rlon    upper right longitude (DEG)                           *
* blat    lower left latitude (DEG)                             *
* tlat    upper right latitude (DEG)                            *
* nuvz    number of vertical model layers (for u,v,T,...)       *
* nwz     number of vertical model layers (for w)               *
* nlev_ec number of vertical model layers total                 *
* ktrunc  Spectral truncation needed                            *
*                                                               *
* (3) Further informations for job control:                     *
*                                                               *
* firstcall    (re-)create new executable routine PRECONVERT    *
* update       dates after 19950405 --> Changes in Mars archive *
* new3dvar     dates after 19960130 --> Introduction of 3D-VAR  *
* uname        user name (ecgate1)                              *
* instdir      installation directory                           *
* fluxdir      ecfile directory containing flux input data      *
* metedir      ecfile directory where output is saved           *
*                                                               *
*****************************************************************
*                                                               *
* OUTPUT:                                                       *
*                                                               *
* job file named job.prepo in catalog /tmp                      *
* If job file is already existing, new job is appended to it.   *
*                                                               *
*****************************************************************

      implicit none

      integer jmd,ih,ios,nuvz,nwz,nx,ny,ian_next
      integer ian_last
      integer enday,nlev_ec,ktrunc,leni,lenf,lenm
      real resol,llon,rlon,blat,tlat
      character datex*8,timex*2,timex_next*2
      character timex_last*2
      character llonstr*6,rlonstr*6,blatstr*5,tlatstr*5,resstr*3
      character endayex*6
      character uname*3,instdir*80,fluxdir*80,metedir*80
      character ctrunc*4
      logical firstcall,update,new3dvar

      leni=index(instdir,' ')-1
      lenf=index(fluxdir,' ')-1
      lenm=index(metedir,' ')-1
      write(ctrunc ,'(i4)') ktrunc

      enday=mod(jmd,1000000)
      write(endayex,'(i6.6)') enday

      write(datex,'(i8.8)') jmd
      write(timex,'(i2.2)') ih
      write(llonstr,'(f6.1)') llon
      write(rlonstr,'(f6.1)') rlon
      write(blatstr,'(f5.1)') blat
      write(tlatstr,'(f5.1)') tlat
      write(resstr,'(f3.1)') resol
*
* CREATING OF JOB FILE
*
      open(101,file='/tmp/job.prepo.'//uname,status='new',iostat=ios)
      close(101)

      open(101,file='/tmp/job.prepo.'//uname,access='append')
      if(ios.eq.0) then                ! CREATE NEW JOB FILE
         write(101,5) '#QSUB -r METprepro'
         write(101,5) '#QSUB -eo'
         write(101,5) '#QSUB -s /bin/ksh'
         write(101,5) '#QSUB -lM 400Mb'
         write(101,5) '#QSUB -lm 400Mb'
         write(101,5) '#QSUB -lT 3000'
         write(101,5) '#QSUB -lt 3000'
         write(101,5) '#QSUB -mb'
         write(101,5) '#QSUB -me'
         write(101,5) '#QSUB'
      endif

      write(101,5) 'PATH=$PATH:.'
      write(101,10) 'DAY='//datex
      write(101,10) 'ENDAY='//endayex
      write(101,10) 'HOUR='//timex

      write(101,5) 'export PATH'
      write(101,5) 'export DAY'
      write(101,5) 'export HOUR'
      write(101,5) 'export ENDAY'
c      write(101,5) 'export RESOL'
      write(101,5) 'cd $TMPDIR'

* CREATE EXECUTABLE PROGRAMME CONVERT_PRE OR CONVERT_TRA
* SET PATHS BELOW CORRECTLY!

      if(ios.eq.0) then
        nx=int((rlon-llon)/resol)+1
        ny=int((tlat-blat)/resol)+1
        call makeinclude(llon,blat,resol,resol,nx,ny,nuvz,nwz,
     &    nlev_ec,ktrunc)
        write(101,5) 'cp '//instdir(1:leni)//'includepar $TMPDIR'
      endif

      if(firstcall) then

        if(update) then
* Q IS STORED AT GAUSSIAN GRID
          write(101,5)
     &    'ar -qv arfile1 /home/ms/spdetraj/xxx/preconvert.qgg/*.f'
          write(101,5) 'ar -xv arfile1'
*          write(101,5) 'frt *.f $EMOSLIB'
          write(101,5) 'f77 *.f $EMOSLIB'
          write(101,5) 'mv a.out CONVERT_PRE'
          write(101,5) 'rm arfile1'
        else
* Q IS STORED AS SPHERICAL HARMONICS
          write(101,5)
     &   'ar -qv arfile1 /home/ms/spdetraj/xxx/preconvert.qsh/*.f'
          write(101,5) 'ar -xv arfile1'
*          write(101,5) 'frt *.f $EMOSLIB'
          write(101,5) 'f77 *.f $EMOSLIB'
          write(101,5) 'mv a.out CONVERT_PRE'
          write(101,5) 'rm arfile1'
        endif
      endif
*
* MARS DIRECTIVES
*
      write(101,5) 'cat >zrequest<<EOF'
      write(101,5) 'RETRIEVE,'
      if (mod(ih,6).eq.0) then
         write(101,5) 'TYPE=AN,'
         write(timex_last,'(i2.2)') ih
      else
         write(101,5) 'TYPE=4V,'
         ian_last=((ih+21)/12)*12+3
         if (ian_last.ge.24) ian_last=ian_last-24
         write(timex_last,'(i2.2)') ian_last
         if(ih.eq.3.or.ih.eq.15) write(101,5) 'STEP=00,'
         if(ih.eq.9.or.ih.eq.21) write(101,5) 'STEP=06,'
      end if
      write(101,5) 'PARAM=T/U/V,'
      write(101,15) 'RESOL=319,'
      write(101,15) 'AREA='//tlatstr//'/'//llonstr//'/'//
     &              blatstr//'/'//rlonstr//','
      write(101,5) 'GRID='//resstr//'/'//resstr//','
      write(101,5) 'LEVTYPE=ML,'
      write(101,5) 'LEVELIST=ALL,'
      write(101,5) 'DATE=$DAY,'
      write(101,5) 'TIME='//timex_last//','
      write(101,5) 'AC=N,'
      write(101,5) 'TARGET="TUVG"'

      write(101,5) 'RETRIEVE,'
      if (mod(ih,6).eq.0) then
         write(101,5) 'TYPE=AN,'
         write(timex_last,'(i2.2)') ih
      else
         write(101,5) 'TYPE=4V,'
         ian_last=((ih+21)/12)*12+3
         if (ian_last.ge.24) ian_last=ian_last-24
         write(timex_last,'(i2.2)') ian_last
         if(ih.eq.3.or.ih.eq.15) write(101,5) 'STEP=00,'
         if(ih.eq.9.or.ih.eq.21) write(101,5) 'STEP=06,'
      end if
      write(101,5) 'PARAM=Q,'
      write(101,15) 'AREA='//tlatstr//'/'//llonstr//'/'//
     &                blatstr//'/'//rlonstr//','
      write(101,5) 'GRID='//resstr//'/'//resstr//','
      write(101,5) 'LEVTYPE=ML,'
      write(101,5) 'LEVELIST=ALL,'
      write(101,5) 'DATE=$DAY,'
      write(101,5) 'TIME='//timex_last//','
      write(101,5) 'AC=N,'
      write(101,5) 'REPRES=GG,'
      write(101,5) 'TARGET="Q_NEW"'
      write(101,5) 'RETRIEVE,'
      if (mod(ih,6).eq.0) then
         write(101,5) 'TYPE=AN,'
         write(timex_last,'(i2.2)') ih
      else
         write(101,5) 'TYPE=4V,'
         ian_last=((ih+21)/12)*12+3
         if (ian_last.ge.24) ian_last=ian_last-24
         write(timex_last,'(i2.2)') ian_last
         if(ih.eq.3.or.ih.eq.15) write(101,5) 'STEP=00,'
         if(ih.eq.9.or.ih.eq.21) write(101,5) 'STEP=06,'
      end if
      write(101,5) 'PARAM=D,'
      write(101,15) 'RESOL=319,'
      write(101,15) 'AREA='//tlatstr//'/'//llonstr//'/'//
     &              blatstr//'/'//rlonstr//','
      write(101,5) 'GRID='//resstr//'/'//resstr//','
      write(101,5) 'LEVTYPE=ML,'
      write(101,5) 'LEVELIST=ALL,'
      write(101,5) 'DATE=$DAY,'
      write(101,5) 'TIME='//timex_last//','
      write(101,5) 'AC=N,'
      write(101,5) 'REPRES=SH,'
      write(101,5) 'TARGET="D_G"'
      write(101,5) 'RETRIEVE,'
      if (mod(ih,6).eq.0) then
         write(101,5) 'TYPE=AN,'
         write(timex_last,'(i2.2)') ih
      else
         write(101,5) 'TYPE=4V,'
         ian_last=((ih+21)/12)*12+3
         if (ian_last.ge.24) ian_last=ian_last-24
         write(timex_last,'(i2.2)') ian_last
         if(ih.eq.3.or.ih.eq.15) write(101,5) 'STEP=00,'
         if(ih.eq.9.or.ih.eq.21) write(101,5) 'STEP=06,'
      end if
      write(101,5) 'PARAM=LNSP,'
      write(101,5) 'AREA=G,'
      write(101,5) 'GRID=OFF,'
      write(101,5) 'LEVTYPE=ML,'
      write(101,15) 'RESOL='//ctrunc//','
      write(101,5) 'DATE=$DAY,'
      write(101,5) 'TIME='//timex_last//','
      write(101,5) 'AC=N,'
      write(101,5) 'TARGET="LNIA"'
      write(101,5) 'RETRIEVE,'
      if (mod(ih,6).eq.0) then
         write(101,5) 'TYPE=AN,'
         write(timex_last,'(i2.2)') ih
      else
         write(101,5) 'TYPE=4V,'
         ian_last=((ih+21)/12)*12+3
         if (ian_last.ge.24) ian_last=ian_last-24
         write(timex_last,'(i2.2)') ian_last
         if(ih.eq.3.or.ih.eq.15) write(101,5) 'STEP=00,'
         if(ih.eq.9.or.ih.eq.21) write(101,5) 'STEP=06,'
      end if
      write(101,5) 'PARAM=SD/MSL/TCC/10U/10V/2T/2D,'
      write(101,15) 'AREA='//tlatstr//'/'//llonstr//'/'//
     &           blatstr//'/'//rlonstr//','
      write(101,5) 'GRID='//resstr//'/'//resstr//','
      write(101,5) 'LEVTYPE=SFC,'
      write(101,5) 'LEVELIST=OFF,'
      write(101,5) 'REPRES=GG,'
      write(101,5) 'DATE=$DAY,'
      write(101,5) 'TIME='//timex_last//','
      write(101,5) 'AC=N,'
      write(101,5) 'TARGET="SURF"'

* RETRIEVE ORO AND LSM

      ian_next=ih/6 * 6
      write(timex_next,'(i2.2)') ian_next
      write(101,5) 'RETRIEVE,'
      write(101,5) 'CLASS=OD,'
      write(101,5) 'TYPE=AN,'
      write(101,5) 'PARAM=Z/LSM/SDOR/VEG/SR/LCC/MCC/HCC/SKT/STL1/SWL1,'
      write(101,15) 'AREA='//tlatstr//'/'//llonstr//'/'//
     &           blatstr//'/'//rlonstr//','
      write(101,5) 'GRID='//resstr//'/'//resstr//','
      write(101,5) 'REPRES=GG,'
      write(101,5) 'LEVTYPE=SFC,'
      write(101,5) 'LEVELIST=OFF,'
      write(101,5) 'DATE=$DAY,'
      write(101,5) 'TIME='//timex_next//','
      write(101,5) 'STEP=00,'
      write(101,5) 'TARGET="OROLSM"'

      write(101,5) 'END'
      write(101,5) 'EOF'

      write(101,5) 'mars zrequest'

      write(101,5) 'mv TUVG fort.11'
      if(update) write(101,5) 'mv Q_NEW fort.17'
      write(101,5) 'mv D_G fort.13'
      write(101,5) 'mv LNIA fort.12'
      write(101,5) 'mv SURF fort.14'
      write(101,5) 'ecp '//fluxdir(1:lenf)//'flux'//datex//timex//
     &  ' fort.16'
      write(101,5) 'CONVERT_PRE'
      write(101,5) 'fname=EN$ENDAY$HOUR'
 
      write(101,5) 'export fname'
      write(101,5) 'ecp -o fort.15 '//metedir(1:lenm)//'$fname'
      write(101,5) 'rm fort.11'
      write(101,5) 'rm fort.12'
      write(101,5) 'rm fort.13'
      write(101,5) 'rm fort.14'
      write(101,5) 'rm fort.15'
      write(101,5) 'rm fort.16'
      if(update) write(101,5) 'rm fort.17'
      write(101,5) 'rm OROLSM'
5     format(a)
10    format(2a)
15    format(9a)
20    format(5a)
      close(101)
      if(ios.eq.0) then
         write(*,*) ' JOBFILE CREATED: /tmp/job.prepo.'//uname
      else
         write(*,*) ' NEW JOB APPENDED TO JOBFILE'
      endif
      return
      end
